@@ -15,10 +15,10 @@
 """Metadata Module.
 
 Source repository: https://github.com/awslabs/aws-ddk
-Documentation: TBD
+Documentation: https://awslabs.github.io/aws-ddk/
 """
 
-__version__: str = "0.1.3"
+__version__: str = "0.4.1"
 __title__: str = "aws_ddk_core"
 __description__: str = "AWS DataOps Development Kit - Core"
 __license__: str = "Apache-2.0"
