@@ -12,14 +12,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from aws_ddk_core.resources._dms import DMSFactory
+from aws_ddk_core.resources._glue import GlueFactory
+from aws_ddk_core.resources._kinesis_firehose import KinesisFirehoseFactory
+from aws_ddk_core.resources._kinesis_streams import KinesisStreamsFactory
 from aws_ddk_core.resources._kms import KMSFactory
 from aws_ddk_core.resources._lambda import LambdaFactory
 from aws_ddk_core.resources._s3 import S3Factory
+from aws_ddk_core.resources._sfn import StepFunctionsFactory
 from aws_ddk_core.resources._sqs import SQSFactory
 
 __all__ = [
+    "DMSFactory",
+    "GlueFactory",
+    "KinesisFirehoseFactory",
+    "KinesisStreamsFactory",
     "KMSFactory",
     "LambdaFactory",
     "S3Factory",
     "SQSFactory",
+    "StepFunctionsFactory",
 ]
