@@ -12,12 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from aws_ddk_core.stages.appflow_ingestion import AppFlowIngestionStage
+from aws_ddk_core.stages.athena_sql import AthenaSQLStage
+from aws_ddk_core.stages.dms_s3_to_s3 import DMSS3ToS3Stage
 from aws_ddk_core.stages.glue_transform import GlueTransformStage
+from aws_ddk_core.stages.kinesis_s3 import KinesisToS3Stage
 from aws_ddk_core.stages.s3_event import S3EventStage
 from aws_ddk_core.stages.sqs_lambda import SqsToLambdaStage
 
 __all__ = [
+    "AppFlowIngestionStage",
+    "AthenaSQLStage",
+    "DMSS3ToS3Stage",
     "GlueTransformStage",
+    "KinesisToS3Stage",
     "S3EventStage",
     "SqsToLambdaStage",
 ]
